==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/tripcore/TRIPCapabilityInfo.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */



static const char* const TRIPCapabilityInfo_cxx_Version = 
"$Id: TRIPCapabilityInfo.cxx,v 1.2 2000/11/06 18:38:19 surendra Exp $";

#include "TRIPCapabilityInfo.hxx"
#include "cpLog.h"


TRIPCapabilityInfo::TRIPCapabilityInfo(const TRIPCapabilityInfo& other) 
{
     copyObj(other);
}

TRIPCapabilityInfo& 
TRIPCapabilityInfo::operator=(const TRIPCapabilityInfo& other)
{
    if(this != &other)
    {
        copyObj(other);
    }
    return(*this);
}

void 
TRIPCapabilityInfo::addCapability(Sptr<TRIPCapability> data)
{
    _capabilityList.push_back(data);
    _paramLength += data->getLength();
}

void 
TRIPCapabilityInfo::dump(ostream& os) const
{
    os.width(25);
    os << "**CapabilityInfo**" << endl;
    CapabilityList::const_iterator itr;
    for(itr = _capabilityList.begin(); 
              itr != _capabilityList.end(); itr++)
    {
         const Sptr<TRIPCapability>& data = (*itr);
         os << *data << endl;
    }
}

void 
TRIPCapabilityInfo::writeData(int id) const throw(VNetworkException&)
{
    TRIPParameter::writeData(id);
    CapabilityList::const_iterator itr;
    for(itr = _capabilityList.begin(); 
              itr != _capabilityList.end(); itr++)
    {
         const Sptr<TRIPCapability>& data = (*itr);
         data->writeData(id);
    }
}

TRIPCapabilityInfo::TRIPCapabilityInfo(const char* buf) 
        throw (TRIPBadDataException&)
    : TRIPParameter(buf)
{
    ///Parse the Parameter - type and parameter length are 
    //parsed in base class
    parseCapability(buf+4, _paramLength);
}

void
TRIPCapabilityInfo::parseCapability(const char* buf, u_int16_t len)
{
    u_int16_t tLen = 0;
    _paramLength = 0;
    while(tLen < len)
    {
        Sptr<TRIPCapability> tsData;
        u_int16_t cCode;
        u_int16_t cLen;
        memcpy(&cCode, buf+tLen, 2);
        memcpy(&cLen, buf+tLen+2, 2);
        cCode = ntohs(cCode);
        cLen = ntohs(cLen);
        switch(static_cast<TRIPCap_Code>(cCode))
        {
            case TRIP_CAP_ROUTE:
            {
                tsData = new TRIPRouteCapability(buf+tLen);                
                tLen += tsData->getLength();
                addCapability(tsData);
            }
            break;
            case TRIP_CAP_SND_REC:
            {
                tsData = new TRIPTransCapability(buf+tLen);                
                tLen += tsData->getLength();
                addCapability(tsData);
            }
            break;
            default:
            {
                cpLog(LOG_ALERT, "Unsupported capability type (%d)", cCode);
                tLen += cLen;
            }
            break;
        }
    }
}

void 
TRIPCapabilityInfo::copyObj(const TRIPCapabilityInfo& other)
{
    _capabilityList.clear();
    //Length will be set as part of addCapability() method.
    _paramLength = 0;
    _type = other._type;
    CapabilityList::const_iterator itr;
    for(itr = other._capabilityList.begin(); 
              itr != other._capabilityList.end(); itr++)
    {
         const Sptr<TRIPCapability>& data = (*itr);
         addCapability(data);
    }
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/tripcore/TRIPCapabilityInfo.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */



static const char* const TRIPCapabilityInfo_cxx_Version = 
"$Id: TRIPCapabilityInfo.cxx,v 1.5 2001/01/23 02:10:34 sprajpat Exp $";

#include <netinet/in.h>

#include "TRIPCapabilityInfo.hxx"
#include "cpLog.h"


TRIPCapabilityInfo::TRIPCapabilityInfo(const TRIPCapabilityInfo& other) 
{
     copyObj(other);
}

TRIPCapabilityInfo& 
TRIPCapabilityInfo::operator=(const TRIPCapabilityInfo& other)
{
    if(this != &other)
    {
        copyObj(other);
    }
    return(*this);
}

void 
TRIPCapabilityInfo::addCapability(Sptr<TRIPCapability> data)
{
    _capabilityList.push_back(data);
    _paramLength += data->getLength();
}

void 
TRIPCapabilityInfo::dump(ostream& os) const
{
    os.width(25);
    os << "**CapabilityInfo**" << endl;
    for(CapabilityList::const_iterator itr = _capabilityList.begin(); 
              itr != _capabilityList.end(); itr++)
    {
         os << *(*itr) << endl;
    }
}

void 
TRIPCapabilityInfo::writeData(int id) const throw(VNetworkException&)
{
    TRIPParameter::writeData(id);
    CapabilityList::const_iterator itr;
    for(itr = _capabilityList.begin(); 
              itr != _capabilityList.end(); itr++)
    {
         const Sptr<TRIPCapability>& data = (*itr);
         data->writeData(id);
    }
}

TRIPCapabilityInfo::TRIPCapabilityInfo(const char* buf) 
        throw (TRIPBadDataException&)
    : TRIPParameter(buf)
{
    //Parse the Parameter - type and parameter length are 
    //parsed in base class, the parameter header takes 4 bytes which
    //are handled in the base class, so move forward with 4 byte offset
    parseCapability(buf+4, _paramLength);
}

void
TRIPCapabilityInfo::parseCapability(const char* buf, u_int16_t len)
{
    u_int16_t tLen = 0;
    _paramLength = 0;
    while(tLen < len)
    {
        Sptr<TRIPCapability> tsData;
        u_int16_t cCode;
        u_int16_t cLen;
        memcpy(&cCode, buf+tLen, 2);
        memcpy(&cLen, buf+tLen+2, 2);
        cCode = ntohs(cCode);
        cLen = ntohs(cLen);
        switch(static_cast<TRIPCap_Code>(cCode))
        {
            case TRIP_CAP_ROUTE:
            {
                tsData = new TRIPRouteCapability(buf+tLen);                
                tLen += tsData->getLength();
                addCapability(tsData);
            }
            break;
            case TRIP_CAP_SND_REC:
            {
                tsData = new TRIPTransCapability(buf+tLen);                
                tLen += tsData->getLength();
                addCapability(tsData);
            }
            break;
            default:
            {
                cpLog(LOG_ALERT, "Unsupported capability type (%d)", cCode);
                tLen += cLen;
            }
            break;
        }
    }
}

void 
TRIPCapabilityInfo::copyObj(const TRIPCapabilityInfo& other)
{
    _capabilityList.clear();
    //Length will be set as part of addCapability() method.
    _paramLength = 0;
    _type = other._type;
    for(CapabilityList::const_iterator itr = other._capabilityList.begin(); 
              itr != other._capabilityList.end(); itr++)
    {
         addCapability((*itr));
    }
}
